@@ -45,8 +45,8 @@ static gchar *DefaultHeight = "Dialog|GtkWindow::default_height";
 static gchar *Shrink = "Dialog|GtkWindow::allow_shrink";
 static gchar *Grow = "Dialog|GtkWindow::allow_grow";
 static gchar *AutoShrink = "Dialog|GtkWindow::auto_shrink";
-static gchar *WMName = "Dialog|GtkWindow::wmclass_name";
-static gchar *WMClass = "Dialog|GtkWindow::wmclass_class";
+static gchar *IconName = "Dialog|GtkWindow::icon_name";
+static gchar *FocusOnMap = "Dialog|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "Dialog|GtkWindow::resizable";
 static gchar *DestroyWithParent = "Dialog|GtkWindow::destroy_with_parent";
@@ -390,7 +390,7 @@ gb_dialog_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
+					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
 					SkipPager, Decorated, Gravity);
@@ -411,7 +411,7 @@ gb_dialog_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -434,7 +434,7 @@ gb_dialog_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -483,7 +483,7 @@ gb_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 				   Title, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
+				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
 				   SkipPager, Decorated, Gravity);
