@@ -40,8 +40,8 @@ static gchar *DefaultHeight = "GnomeDialog|GtkWindow::default_height";
 static gchar *Shrink = "GnomeDialogl|GtkWindow::allow_shrink";
 static gchar *Grow = "GnomeDialog|GtkWindow::allow_grow";
 static gchar *AutoShrink = "GnomeDialog|GtkWindow::auto_shrink";
-static gchar *WMName = "GnomeDialog|GtkWindow::wmclass_name";
-static gchar *WMClass = "GnomeDialog|GtkWindow::wmclass_class";
+static gchar *IconName = "GnomeDialog|GtkWindow::icon_name";
+static gchar *FocusOnMap = "GnomeDialog|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "GnomeDialog|GtkWindow::resizable";
 static gchar *DestroyWithParent = "GnomeDialog|GtkWindow::destroy_with_parent";
@@ -128,6 +128,9 @@ gb_gnome_dialog_new (GbWidgetNewData *data)
   gtk_signal_connect (GTK_OBJECT (new_widget), "delete_event",
 		      GTK_SIGNAL_FUNC (editor_close_window), NULL);
 
+  gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return new_widget;
 }
 
@@ -142,7 +145,7 @@ gb_gnome_dialog_create_properties (GtkWidget * widget, GbWidgetCreateArgData * d
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
+					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
 					SkipPager, Decorated, Gravity);
@@ -165,7 +168,7 @@ gb_gnome_dialog_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -189,7 +192,7 @@ gb_gnome_dialog_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -229,15 +232,21 @@ static void
 gb_gnome_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 {
   gchar *wname, *child_name;
+  gboolean translatable, context;
+  gchar *comments;
 
   if (data->create_widget)
     {
       gchar *title;
 
+      glade_util_get_translation_properties (widget, Title, &translatable,
+					     &comments, &context);
+      source_add_translator_comments (data, translatable, comments);
+
       title = GTK_WINDOW (widget)->title;
       source_add (data, "  %s = gnome_dialog_new (%s, NULL);\n",
 		  data->wname,
-		  title ? source_make_string (title, data->use_gettext)
+		  title ? source_make_string_full (title, data->use_gettext && translatable, context)
 		        : "NULL");
     }
 
@@ -248,7 +257,7 @@ gb_gnome_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data
 				   NULL, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
+				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
 				   SkipPager, Decorated, Gravity);
